.colM .aligned .vLargeTextField {
    width: 100%;
}

form .redactor-box {
    display: inline-block;
    width: 100%;
}

form .redactor-box textarea {
    max-height: 100%;
    max-width: 100%;
}

form .aligned ul {
    margin: 0 0 0 1.5em;
    padding: 0;
}

form .aligned ul li {
    list-style: inherit;
}
